@@ -4,12 +4,12 @@ use warnings;
 use 5.012000;
 use utf8;
 use feature 'unicode_strings';
-use version 0.77; our $VERSION = version->declare('v0.1.1');
+use version 0.77; our $VERSION = version->declare('v0.2.0');
 use Lingua::LO::NLP::Syllabify;
 use Lingua::LO::NLP::Analyze;
 use Lingua::LO::NLP::Romanize;
 
-=encoding UTF-8
+=encoding utf8
 
 =head1 NAME
 
@@ -45,12 +45,18 @@ This module provides various functions for processing Lao text. Currently it can
 
 =over 4
 
-=item split Lao text (usually written without blanks between words) into syllables
+=item
 
-=item analyze syllables with regards to core and end consonants, vowels, tone and
+split Lao text (usually written without blanks between words) into syllables
+
+=item
+
+analyze syllables with regards to core and end consonants, vowels, tone and
 other properties
 
-=item romanize Lao text according to the PCGN standard or to IPA (experimental)
+=item
+
+romanize Lao text according to the PCGN standard or to IPA (experimental)
 
 =back
 
@@ -144,3 +150,5 @@ University of California. All modified versions must retain the file COPYRIGHT
 included in the distribution.
 
 =cut
+
+1;
