@@ -5,12 +5,12 @@ use 5.012000;
 use utf8;
 use feature qw/ unicode_strings say /;
 use charnames qw/ :full lao /;
-use version 0.77; our $VERSION = version->declare('v0.0.1');
+use version 0.77; our $VERSION = version->declare('v0.2.0');
 use Carp;
 use Class::Accessor::Fast 'antlers';
-use Lingua::LO::NLP::Data qw/ is_long_vowel normalize_tone_marks /;
+use Lingua::LO::NLP::Data ':all';
 
-=encoding UTF-8
+=encoding utf8
 
 =head1 NAME
 
@@ -59,46 +59,45 @@ my %TONE_MARKS = (
 );
 
 my %CONSONANTS = (
-   ກ  => 'KANG',
-   ຂ  => 'SUNG',
-   ຄ  => 'TAM',
-   ງ  => 'TAM',
-   ຈ  => 'KANG',
-   ສ  => 'SUNG',
-   ຊ  => 'TAM',
-   ຍ  => 'TAM',
-   ດ  => 'KANG',
-   ຕ  => 'KANG',
-   ຖ  => 'SUNG',
-   ທ  => 'TAM',
-   ນ  => 'TAM',
-   ບ  => 'KANG',
-   ປ  => 'KANG',
-   ຜ  => 'SUNG',
-   ຝ  => 'SUNG',
-   ພ  => 'TAM',
-   ຟ  => 'TAM',
-   ມ  => 'TAM',
-   ຢ  => 'KANG',
-   ລ  => 'TAM',
-   ວ  => 'TAM',
-   ຫ  => 'SUNG',
-   ອ  => 'KANG',
-   ຮ  => 'TAM',
-   ຣ  => 'TAM',
-   ຫງ => 'SUNG',
-   ຫຍ => 'SUNG',
-   ຫນ => 'SUNG',
-   ໜ  => 'SUNG',
-   ຫມ => 'SUNG',
-   ໝ  => 'SUNG',
-   ຫລ => 'SUNG',
-   ຫຼ  => 'SUNG',
-   ຫວ => 'SUNG',
+   'ກ'  => 'KANG',
+   'ຂ'  => 'SUNG',
+   'ຄ'  => 'TAM',
+   'ງ'  => 'TAM',
+   'ຈ'  => 'KANG',
+   'ສ'  => 'SUNG',
+   'ຊ'  => 'TAM',
+   'ຍ'  => 'TAM',
+   'ດ'  => 'KANG',
+   'ຕ'  => 'KANG',
+   'ຖ'  => 'SUNG',
+   'ທ'  => 'TAM',
+   'ນ'  => 'TAM',
+   'ບ'  => 'KANG',
+   'ປ'  => 'KANG',
+   'ຜ'  => 'SUNG',
+   'ຝ'  => 'SUNG',
+   'ພ'  => 'TAM',
+   'ຟ'  => 'TAM',
+   'ມ'  => 'TAM',
+   'ຢ'  => 'KANG',
+   'ລ'  => 'TAM',
+   'ວ'  => 'TAM',
+   'ຫ'  => 'SUNG',
+   'ອ'  => 'KANG',
+   'ຮ'  => 'TAM',
+   'ຣ'  => 'TAM',
+   'ຫງ' => 'SUNG',
+   'ຫຍ' => 'SUNG',
+   'ຫນ' => 'SUNG',
+   'ໜ'  => 'SUNG',
+   'ຫມ' => 'SUNG',
+   'ໝ'  => 'SUNG',
+   'ຫລ' => 'SUNG',
+   'ຫຼ'  => 'SUNG',
+   'ຫວ' => 'SUNG',
 );
 
-my %H_COMBINERS = map { $_ => 1 } qw/ ຍ ວ /;
-my %CONS_H_MNL = ( ມ => 'ໝ', ນ => 'ໜ', ລ => "\N{LAO SEMIVOWEL SIGN LO}" );
+my %CONS_H_MNL = ( 'ມ' => 'ໝ', 'ນ' => 'ໜ', 'ລ' => "\N{LAO SEMIVOWEL SIGN LO}" );
 
 =head1 METHODS
 
@@ -124,12 +123,12 @@ sub new {
 }
 
 {
-    my $regexp = Lingua::LO::NLP::Data::get_sylre_named;
+    my $regexp = get_sylre_named();
 
     sub _classify {
-        my $s = shift // croak("syllable argument missing");
+        my $s = shift // croak("`syllable' argument missing or undefined");
 
-        $s =~ /^$regexp/ or croak "`$s' does not start with a valid syllable";
+        $s =~ /^$regexp/ or croak("`$s' does not start with a valid syllable");
         my %class = ( syllable => $s, parse => { %+ } );
         (my $consonant, @class{qw/ end_consonant h semivowel tone_mark /}) = @+{qw/ consonant end_consonant h semivowel tone_mark /};
 
@@ -150,7 +149,7 @@ sub new {
             } else {
                 # If there is a preceding vowel, it uses the ຫ as a consonant and the
                 # one parsed as core consonant is actually an end consonant
-                unless(exists $H_COMBINERS{ $consonant }) {
+                unless($consonant eq 'ວ' or $consonant eq 'ຍ') {
                     $class{end_consonant} = $consonant;
                     $consonant = 'ຫ';
                     delete $class{h};
